import React from 'react';
import './style/index.less';
export interface SplitProps extends Omit<React.HTMLAttributes<HTMLDivElement>, 'onDragEnd'> {
    style?: React.CSSProperties;
    className?: string;
    prefixCls?: string;
    /**
     * Drag width/height change callback function,
     * the width or height is determined according to the mode parameter
     */
    onDragging?: (preSize: number, nextSize: number, paneNumber: number) => void;
    /** Callback function for dragging end */
    onDragEnd?: (preSize: number, nextSize: number, paneNumber: number) => void;
    /** Support custom drag and drop toolbar */
    renderBar?: (props: React.HTMLAttributes<HTMLDivElement>) => JSX.Element;
    /** Set the drag and drop toolbar as a line style. */
    lineBar?: boolean;
    /** Set the dragged toolbar, whether it is visible or not */
    visiable?: boolean | number[];
    /**
     * Set the drag and drop toolbar, disable
     */
    disable?: boolean | number[];
    /**
     * type, optional `horizontal` or `vertical`
     */
    mode?: 'horizontal' | 'vertical';
}
export interface SplitState {
    dragging: boolean;
}
export default class Split extends React.Component<SplitProps, SplitState> {
    static defaultProps: SplitProps;
    state: SplitState;
    warpper: HTMLDivElement | null;
    paneNumber: number;
    startX: number;
    startY: number;
    move: boolean;
    target: HTMLDivElement;
    boxWidth: number;
    boxHeight: number;
    preWidth: number;
    nextWidth: number;
    preHeight: number;
    nextHeight: number;
    preSize: number;
    nextSize: number;
    constructor(props: SplitProps);
    componentWillUnmount(): void;
    private removeEvent;
    onMouseDown(paneNumber: number, env: React.MouseEvent<HTMLDivElement, MouseEvent>): void;
    onDragging(env: Event): void;
    onDragEnd(): void;
    render(): JSX.Element;
}
